# 快手

#### 介绍
史上最简单的跨平台 GUI (图形界面) 开发工具 - 快手 (PySimpleGUI 中文版)

#### 安装

python -m pip install --upgrade grasspy-pysimplegui

#### 使用说明

1.  示例位于本代码库的 tests 目录中
2.  [pysimplegui 文档](http://www.PySimpleGUI.org)

